==> 2.9.zip: piwigo/language/dv_MV/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Dhivehi [MV]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=570
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "Dhivehi";
$lang_info['country'] = "Maldives";
$lang_info['direction'] = "rtl";
$lang_info['code'] = "dv";
$lang_info['zero_plural'] = false;

$lang['%d album updated'] = '%d އަލްބަމް އާކުރެވިފަ';
$lang['%d albums updated'] = '%d އަލްބަމްތައް އާކުރެވިފަ';
$lang['%d comment to validate'] = '%d ޞައްހަކުރެއްވުމަށް ޙިޔާލެއް އެބައިން';
$lang['%d comments to validate'] = '%d ޞައްހަކުރެއްވުމަށް ހުރި ޙިޔާލުތައް';
$lang['%d new comment'] = '%d އާ ޙިޔާލު';
$lang['%d new comments'] = '%d އާ ޙިޔާލުތައް';
$lang['%d comment'] = '%d ޙިޔާލު';
$lang['%d comments'] = '%d ޙިޔާލުތައް';
$lang['%d hit'] = '%d ހިޓް';
$lang['%d hits'] = '%d ހިޓްތައް';
$lang['%d new photo'] = '%d އާ ފޮޓޯ';
$lang['%d new photos'] = '%d އާ ފޮޓޯތައް';
$lang['%d new user'] = '%d އާ ޔޫޒާ';
$lang['%d new users'] = '%d އާ ޔޫޒާތައް';
$lang['About'] = 'އާއި ބެހޭ';
$lang['All tags'] = 'ހުރިހާ ޓެގުތައް';
$lang['Any tag'] = 'އެއްވެސް ޓެގެއް';
$lang['At least one listed rule must be satisfied.'] = '.އެންމެ މަދުވެގެން ބަޔާންކުރެވިފައިވާ އެއް ގަވާއިދާ އެއްގޮތްވާންވާނެ';
$lang['Author'] = 'ޝާއިރު';
$lang['Average rate'] = 'އެވެރެޖް ރޭޓް';
$lang['Albums'] = 'އަލްބަމްތައް';
$lang['Album'] = 'އަލްބަމް';
$lang['Close this window'] = 'މި ވިންޑޯ ލައްޕާލާ';
$lang['Complete RSS feed (photos, comments)'] = '(މުޅި އާރު.އެސް.އެސް. ފީޑް (ފޮޓޯތައް, ޙިޔާލުތައް';
$lang['Confirm Password'] = 'ސިއްރުބަހުގެ ޞައްހަކަން ޔަގީންކުރައްވާ';
$lang['Connection settings'] = 'ކަނެކްޝަން ސެޓިންގްސް';
$lang['Login'] = 'ވަންނަވާ';
$lang['Contact webmaster'] = 'ވެރިޔާ އާ ގުޅުއްވާ';
$lang['Create a new account'] = 'އާ އެކައުންޓެއް ހައްދަވާ';
$lang['Created on'] = 'އުފެދިފައިވަނީ';
$lang['Creation date'] = 'އުފެދުނު ތާރިޚު';
$lang['Current password is wrong'] = 'ތި ސިއްރުބަސް ރަންގަޅެއް ނޫން';
$lang['Dimensions'] = 'ޑައިމެންޝަންތައް';
$lang['Display'] = 'ދައްކަވާ';
$lang['Each listed rule must be satisfied.'] = 'ހުރިހާ ޝަރުތުތައް ހުރިހަމަ ވާންވާނެ.';
$lang['Email address'] = 'އީ-މެއިލް އެޑްރެސް';
$lang['Enter your personnal informations'] = 'އަމިއްލަ މައުލޫމާތުތައް ފުރުއްވާ';
$lang['Error sending email'] = 'އީ-މެއިލް ފޮނުވުމުގައި މައްސަލައެއް ޖެހިއްޖެ';
$lang['File name'] = 'ފައިލްގެ ނަން';
$lang['File'] = 'ފައިލް';
$lang['Filesize'] = 'ފައިލްގެ ބޮޑުމިން';
$lang['Filter and display'] = 'ބައިތަކަށް ބެހުމަށް ފަހު ދައްކަވާ';
$lang['Filter'] = 'ބައިތަކަށް ބައްސަވާ';
$lang['Forgot your password?'] = 'ސިއްރު ބަސް ހަންދާން ނެތުނީތޯ؟';
$lang['Go through the gallery as a visitor'] = 'މެހެމާނެއްގެ ގޮތުގައި މައުރަޒު ބައްލަވާ ލައްވާ';
$lang['Help'] = 'އެހީ';
$lang['Identification'] = 'ކާކުކަން ވަކިކުރުން';
$lang['Photos only RSS feed'] = 'ހަމައެކަނި ފޮޓޯ ހިމެނޭ އާރު.އެސް.އެސް. ފީޑް';
$lang['Keyword'] = 'ކީވޯޑް';
$lang['day'][0] = "އާދީއްތަ";
$lang['day'][1] = "ހޯމަ";
$lang['day'][2] = "އަންގާރަ";
$lang['day'][3] = "ބުދަ";
$lang['day'][4] = "ބުރާސްފަތި";
$lang['day'][5] = "ހުކުރު";
$lang['day'][6] = "ހޮނިހިރު";
$lang['month'][10] = "އޮކްޓޯބަރ";
$lang['month'][11] = "ނޮވެމްބަރ";
$lang['month'][12] = "ޑިސެންބަރ";
$lang['month'][1] = "ޖެނުއަރީ";
$lang['month'][2] = "ފެބްރުއަރީ";
$lang['month'][3] = "މާރޗް";
$lang['month'][4] = "އޭޕްރީލް";
$lang['month'][5] = "މޭ";
$lang['month'][6] = "ޖޫން";
$lang['month'][7] = "ޖުލައި";
$lang['month'][8] = "އޮގަސްޓް";
$lang['month'][9] = "ސެޕްޓެމްބަރ";
$lang['Notification'] = 'އެންގުންތައް';
$lang['Number of items'] = 'ތަކެތީގެ އަދަދު';
$lang['Original dimensions'] = 'އޮރިޖިނަލް ޑައިމެންޝަންސް';
$lang['Password forgotten'] = 'ސިއްރުބަސް ހަނދާންނެތިއްޖެ';
$lang['Password'] = 'ސިއްރުބަސް';
$lang['Post date'] = 'ތާރީޙު ޕޯސްޓްކުރޭ';
$lang['Posted on'] = 'ޕޯސްޓްކުރި ތާރީޙު';
$lang['Profile'] = 'ޕްރޮފައިލް';
$lang['Quick connect'] = 'އަވަހަށް ގުޅާލުން';
$lang['RSS feed'] = 'އާރު.އެސް.އެސް. ފީޑު';
$lang['Rate'] = 'ރޭޓްކުރައްވާ';
$lang['Register'] = 'ރެޖިސްޓާކުރައްވާ';
$lang['Registration'] = 'ރެޖިސްޓާކުރުން';
$lang['Related tags'] = 'ގުޅުންހުރި ޓެގުތައް';
$lang['Reset'] = 'ރިސެޓް';
$lang['Retrieve password'] = 'ސިއްރުބަސް ލިބިވަޑައިގަންނަވާ';
$lang['Search rules'] = 'ހޯދުމުގެ ގަވާއިދުތައް';
$lang['Search tags'] = 'ހޯދުމުގެ ޓެގްތައް';
$lang['Search'] = 'ހޯދާ';
$lang['display available tags'] = 'ހުރި ޓެގުތައް ދައްކަވާ';
$lang['Since'] = 'އިން ފެށިގެން';
$lang['Sort by'] = 'ގޮތަކަށް އަތުރާ';
$lang['Sort order'] = 'އެތުރުމުގެ އޯޑަރު';
$lang['Tag'] = 'ޓެގް';
$lang['Tags'] = 'ޓެގުތައް';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'އާރް.އެސް.އެސް. ނޯޓިފިކޭޝަން ފީޑަކުން މިވެބްސައިޓުގެ: އާފޮޓޯ، އަލްބަމް އަޕްޑޭޓްތައް، އާޙިޔާލުތަކާބެހޭ އެންގުންތައް ލިބިވަޑައިގަންނަވާނެއެވެ. އެހެންކަމުން އާރް.އެސް.އެސް. ފީޑް ރީޑަރ އެއް ބޭނުން ކުރައްވާ.';
$lang['Unknown feed identifier'] = 'އިނގިގެންނުވާ، ފީޑް އައިޑެންޓިފަޔާއެއް';
$lang['User comments'] = 'ޔޫސާގެ ޙިޔާލު';
$lang['Username'] = 'ޔޫސާނަން';
$lang['Visits'] = 'ވަޑައިގެންނެވި ފަހަރު';


?>

==> 14.5.0.zip: piwigo/language/dv_MV/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
/*
Language Name: Dhivehi [MV]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=570
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "Dhivehi";
$lang_info['country'] = "Maldives";
$lang_info['direction'] = "rtl";
$lang_info['code'] = "dv";
$lang_info['zero_plural'] = false;

$lang['%d album updated'] = '%d އަލްބަމް އާކުރެވިފަ';
$lang['%d albums updated'] = '%d އަލްބަމްތައް އާކުރެވިފަ';
$lang['%d comment to validate'] = '%d ޞައްހަކުރެއްވުމަށް ޙިޔާލެއް އެބައިން';
$lang['%d comments to validate'] = '%d ޞައްހަކުރެއްވުމަށް ހުރި ޙިޔާލުތައް';
$lang['%d new comment'] = '%d އާ ޙިޔާލު';
$lang['%d new comments'] = '%d އާ ޙިޔާލުތައް';
$lang['%d comment'] = '%d ޙިޔާލު';
$lang['%d comments'] = '%d ޙިޔާލުތައް';
$lang['%d hit'] = '%d ހިޓް';
$lang['%d hits'] = '%d ހިޓްތައް';
$lang['%d new photo'] = '%d އާ ފޮޓޯ';
$lang['%d new photos'] = '%d އާ ފޮޓޯތައް';
$lang['%d new user'] = '%d އާ ޔޫޒާ';
$lang['%d new users'] = '%d އާ ޔޫޒާތައް';
$lang['About'] = 'އާއި ބެހޭ';
$lang['All tags'] = 'ހުރިހާ ޓެގުތައް';
$lang['Any tag'] = 'އެއްވެސް ޓެގެއް';
$lang['At least one listed rule must be satisfied.'] = '.އެންމެ މަދުވެގެން ބަޔާންކުރެވިފައިވާ އެއް ގަވާއިދާ އެއްގޮތްވާންވާނެ';
$lang['Author'] = 'ޝާއިރު';
$lang['Average rate'] = 'އެވެރެޖް ރޭޓް';
$lang['Albums'] = 'އަލްބަމްތައް';
$lang['Album'] = 'އަލްބަމް';
$lang['Close this window'] = 'މި ވިންޑޯ ލައްޕާލާ';
$lang['Complete RSS feed (photos, comments)'] = '(މުޅި އާރު.އެސް.އެސް. ފީޑް (ފޮޓޯތައް, ޙިޔާލުތައް';
$lang['Confirm Password'] = 'ސިއްރުބަހުގެ ޞައްހަކަން ޔަގީންކުރައްވާ';
$lang['Connection settings'] = 'ކަނެކްޝަން ސެޓިންގްސް';
$lang['Login'] = 'ވަންނަވާ';
$lang['Contact webmaster'] = 'ވެރިޔާ އާ ގުޅުއްވާ';
$lang['Create a new account'] = 'އާ އެކައުންޓެއް ހައްދަވާ';
$lang['Created on'] = 'އުފެދިފައިވަނީ';
$lang['Creation date'] = 'އުފެދުނު ތާރިޚު';
$lang['Current password is wrong'] = 'ތި ސިއްރުބަސް ރަންގަޅެއް ނޫން';
$lang['Dimensions'] = 'ޑައިމެންޝަންތައް';
$lang['Display'] = 'ދައްކަވާ';
$lang['Each listed rule must be satisfied.'] = 'ހުރިހާ ޝަރުތުތައް ހުރިހަމަ ވާންވާނެ.';
$lang['Email address'] = 'އީ-މެއިލް އެޑްރެސް';
$lang['Enter your personnal informations'] = 'އަމިއްލަ މައުލޫމާތުތައް ފުރުއްވާ';
$lang['Error sending email'] = 'އީ-މެއިލް ފޮނުވުމުގައި މައްސަލައެއް ޖެހިއްޖެ';
$lang['File name'] = 'ފައިލްގެ ނަން';
$lang['File'] = 'ފައިލް';
$lang['Filesize'] = 'ފައިލްގެ ބޮޑުމިން';
$lang['Filter and display'] = 'ބައިތަކަށް ބެހުމަށް ފަހު ދައްކަވާ';
$lang['Filter'] = 'ބައިތަކަށް ބައްސަވާ';
$lang['Forgot your password?'] = 'ސިއްރު ބަސް ހަންދާން ނެތުނީތޯ؟';
$lang['Go through the gallery as a visitor'] = 'މެހެމާނެއްގެ ގޮތުގައި މައުރަޒު ބައްލަވާ ލައްވާ';
$lang['Help'] = 'އެހީ';
$lang['Identification'] = 'ކާކުކަން ވަކިކުރުން';
$lang['Photos only RSS feed'] = 'ހަމައެކަނި ފޮޓޯ ހިމެނޭ އާރު.އެސް.އެސް. ފީޑް';
$lang['Keyword'] = 'ކީވޯޑް';
$lang['day'][0] = "އާދީއްތަ";
$lang['day'][1] = "ހޯމަ";
$lang['day'][2] = "އަންގާރަ";
$lang['day'][3] = "ބުދަ";
$lang['day'][4] = "ބުރާސްފަތި";
$lang['day'][5] = "ހުކުރު";
$lang['day'][6] = "ހޮނިހިރު";
$lang['month'][10] = "އޮކްޓޯބަރ";
$lang['month'][11] = "ނޮވެމްބަރ";
$lang['month'][12] = "ޑިސެންބަރ";
$lang['month'][1] = "ޖެނުއަރީ";
$lang['month'][2] = "ފެބްރުއަރީ";
$lang['month'][3] = "މާރޗް";
$lang['month'][4] = "އޭޕްރީލް";
$lang['month'][5] = "މޭ";
$lang['month'][6] = "ޖޫން";
$lang['month'][7] = "ޖުލައި";
$lang['month'][8] = "އޮގަސްޓް";
$lang['month'][9] = "ސެޕްޓެމްބަރ";
$lang['Notification'] = 'އެންގުންތައް';
$lang['Number of items'] = 'ތަކެތީގެ އަދަދު';
$lang['Original dimensions'] = 'އޮރިޖިނަލް ޑައިމެންޝަންސް';
$lang['Password forgotten'] = 'ސިއްރުބަސް ހަނދާންނެތިއްޖެ';
$lang['Password'] = 'ސިއްރުބަސް';
$lang['Post date'] = 'ތާރީޙު ޕޯސްޓްކުރޭ';
$lang['Posted on'] = 'ޕޯސްޓްކުރި ތާރީޙު';
$lang['Profile'] = 'ޕްރޮފައިލް';
$lang['Quick connect'] = 'އަވަހަށް ގުޅާލުން';
$lang['RSS feed'] = 'އާރު.އެސް.އެސް. ފީޑު';
$lang['Rate'] = 'ރޭޓްކުރައްވާ';
$lang['Register'] = 'ރެޖިސްޓާކުރައްވާ';
$lang['Registration'] = 'ރެޖިސްޓާކުރުން';
$lang['Related tags'] = 'ގުޅުންހުރި ޓެގުތައް';
$lang['Reset'] = 'ރިސެޓް';
$lang['Retrieve password'] = 'ސިއްރުބަސް ލިބިވަޑައިގަންނަވާ';
$lang['Search rules'] = 'ހޯދުމުގެ ގަވާއިދުތައް';
$lang['Search tags'] = 'ހޯދުމުގެ ޓެގްތައް';
$lang['Search'] = 'ހޯދާ';
$lang['display available tags'] = 'ހުރި ޓެގުތައް ދައްކަވާ';
$lang['Since'] = 'އިން ފެށިގެން';
$lang['Sort by'] = 'ގޮތަކަށް އަތުރާ';
$lang['Sort order'] = 'އެތުރުމުގެ އޯޑަރު';
$lang['Tag'] = 'ޓެގް';
$lang['Tags'] = 'ޓެގުތައް';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'އާރް.އެސް.އެސް. ނޯޓިފިކޭޝަން ފީޑަކުން މިވެބްސައިޓުގެ: އާފޮޓޯ، އަލްބަމް އަޕްޑޭޓްތައް، އާޙިޔާލުތަކާބެހޭ އެންގުންތައް ލިބިވަޑައިގަންނަވާނެއެވެ. އެހެންކަމުން އާރް.އެސް.އެސް. ފީޑް ރީޑަރ އެއް ބޭނުން ކުރައްވާ.';
$lang['Unknown feed identifier'] = 'އިނގިގެންނުވާ، ފީޑް އައިޑެންޓިފަޔާއެއް';
$lang['User comments'] = 'ޔޫސާގެ ޙިޔާލު';
$lang['Username'] = 'ޔޫސާނަން';
$lang['Visits'] = 'ވަޑައިގެންނެވި ފަހަރު';


?>
